
.. _algorithms/planar:

Planar
******

Algorithms
----------

The following algorithms are available:

.. automodule:: jgrapht.algorithms.planar
   :members:


Types
-----

Combinatorial embeddings are represented using instances of the following class.

.. autoclass:: jgrapht.types.PlanarEmbedding
   :members: